summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/3rdparty/sqlite/sqliteInt.h
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/3rdparty/sqlite/sqliteInt.h')
-rw-r--r--experimental/tqtinterface/qt4/src/3rdparty/sqlite/sqliteInt.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/experimental/tqtinterface/qt4/src/3rdparty/sqlite/sqliteInt.h b/experimental/tqtinterface/qt4/src/3rdparty/sqlite/sqliteInt.h
index e435a1d44..aea82717e 100644
--- a/experimental/tqtinterface/qt4/src/3rdparty/sqlite/sqliteInt.h
+++ b/experimental/tqtinterface/qt4/src/3rdparty/sqlite/sqliteInt.h
@@ -5,7 +5,7 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
*************************************************************************
@@ -442,7 +442,7 @@ struct Column {
u8 notNull; /* True if there is a NOT NULL constraint */
u8 isPrimKey; /* True if this column is part of the PRIMARY KEY */
u8 sortOrder; /* Some combination of STQLITE_SO_... values */
- u8 dottedName; /* True if zName tqcontains a "." character */
+ u8 dottedName; /* True if zName contains a "." character */
};
/*
@@ -510,7 +510,7 @@ struct Table {
** Each foreign key constraint is an instance of the following structure.
**
** A foreign key is associated with two tables. The "from" table is
** the table that tqcontains the REFERENCES clause that creates the foreign
** key. The "to" table is the table that is named in the REFERENCES clause.
** Consider this example:
**
@@ -789,7 +789,7 @@ struct SrcList {
/*
** For each nested loop in a WHERE clause implementation, the WhereInfo
** structure tqcontains a single instance of this structure. This structure
** is intended to be private the the where.c module and should not be
** access or modified by other modules.
*/
@@ -826,7 +826,7 @@ struct WhereInfo {
};
/*
** An instance of the following structure tqcontains all information
** needed to generate code for a single SELECT statement.
**
** The zSelect field is used when the Select structure must be persistent.
@@ -892,7 +892,7 @@ struct Select {
** If AggExpr.pExpr==0, that means the expression is "count(*)".
*/
struct AggExpr {
- int isAgg; /* if TRUE tqcontains an aggregate function */
+ int isAgg; /* if TRUE contains an aggregate function */
Expr *pExpr; /* The expression */
FuncDef *pFunc; /* Information about the aggregate function */
};
@@ -1038,7 +1038,7 @@ struct TriggerStep {
* "pTriggerStack" member of the Parse structure.
*
* The pTab member points to the table that triggers are being coded on. The
* newIdx member tqcontains the index of the vdbe cursor that points at the temp
* table that stores the new.* references. If new.* references are not valid
* for the trigger being coded (for example an ON DELETE trigger), then newIdx
* is set to -1. The oldIdx member is analogous to newIdx, for old.* references.
@@ -1069,7 +1069,7 @@ struct TriggerStack {
};
/*
** The following structure tqcontains information used by the sqliteFix...
** routines as they walk the parse tree to make database references
** explicit.
*/
@@ -510,7 +510,7 @@ struct Table {
**
** A foreign key is associated with two tables. The "from" table is
-** the table that tqcontains the REFERENCES clause that creates the foreign
+** the table that contains the REFERENCES clause that creates the foreign
** key. The "to" table is the table that is named in the REFERENCES clause.
** Consider this example:
@@ -789,7 +789,7 @@ struct SrcList {
/*
** For each nested loop in a WHERE clause implementation, the WhereInfo
-** structure tqcontains a single instance of this structure. This structure
+** structure contains a single instance of this structure. This structure
** is intended to be private the the where.c module and should not be
** access or modified by other modules.
@@ -826,7 +826,7 @@ struct WhereInfo {
};
/*
-** An instance of the following structure tqcontains all information
+** An instance of the following structure contains all information
** needed to generate code for a single SELECT statement.
**
@@ -1038,7 +1038,7 @@ struct TriggerStep {
*
* The pTab member points to the table that triggers are being coded on. The
- * newIdx member tqcontains the index of the vdbe cursor that points at the temp
+ * newIdx member contains the index of the vdbe cursor that points at the temp
* table that stores the new.* references. If new.* references are not valid
* for the trigger being coded (for example an ON DELETE trigger), then newIdx
@@ -1069,7 +1069,7 @@ struct TriggerStack {
};
/*
-** The following structure tqcontains information used by the sqliteFix...
+** The following structure contains information used by the sqliteFix...
** routines as they walk the parse tree to make database references
** explicit.